#!/usr/local/bin/python2.7

"""
This script runs the file integrity checker 'Spot The Difference'.
An integrity checker detects signs of intrusions looking for suspicious changes
in system files.
It works in two phases:
- the 'update' phase, in which it creates a database reflecting the state of the
  filesystem in a moment the system administrator is sure about its integrity;
- the 'check' phase, in which the current state of the filesystem is compared to
  the database records.
Synopsis:

stdiff.py [-h] [-v|-q] [-C config_file] [-c|-u] [-o output_file] [-e]

-C, --configfile  Specify the configuration file. Default is '/etc/stdiff.conf'
-u, --update      Create a new 'known-state' database
-c, --check       Check the filesystem integrity
-o, --outfile     Specify the filename of the final report (default is
                  './stdiff.out')
-e, --email       Turn on email notification
-v, --verbose     Verbose mode
-q, --quiet       Quiet (almost numb) mode
-h, --help        Print a short help message and exit
"""

from spot import Parser
from sys  import exit


# List of supported databases
supported_DBs = ["mysql", "pgsql", "sqlite", "dbm"]


if __name__ == "__main__":
    # Parse the command line
    options, args = Parser.parse_options()

    # Parse the configuration file
    if options.verbose:
        print "Parsing configuration file '%s'" % options.cfg_file
    paths, vars_ = Parser.cfg_parse(options.cfg_file)

    if not vars_.has_key("db_type"):
        exit("\nVariable 'db_type' not defined in '%s'\n" % options.cfg_file)

    elif vars_["db_type"] not in supported_DBs:
        exit("\nDatabase type '%s' not supported\n" % vars_["db_type"])

    else:
        exec("from spot import spot_%s as s" % vars_["db_type"])
        s.spot(options, paths, vars_).go()

